summaryrefslogtreecommitdiff
path: root/gdb/frame.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/frame.h')
-rw-r--r--gdb/frame.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/gdb/frame.h b/gdb/frame.h
index d154b9408ce..b7ab53031cc 100644
--- a/gdb/frame.h
+++ b/gdb/frame.h
@@ -27,13 +27,13 @@
/* XXXX - deprecated */
struct frame_saved_regs
{
+ /* For each register R (except the SP), regs[R] is the address at
+ which it was saved on entry to the frame, or zero if it was not
+ saved on entry to this frame. This includes special registers
+ such as pc and fp saved in special ways in the stack frame.
- /* For each register, address of where it was saved on entry to
- the frame, or zero if it was not saved on entry to this frame.
- This includes special registers such as pc and fp saved in
- special ways in the stack frame. The SP_REGNUM is even more
- special, the address here is the sp for the next frame, not the
- address where the sp was saved. */
+ regs[SP_REGNUM] is different. It holds the actual SP, not the
+ address at which it was saved. */
CORE_ADDR regs[NUM_REGS];
};